/* Copyright (C) 2002 Bjoern Beutel. */

/* Description. =============================================================*/

/* Read in and display Malaga Results. */

/* Variables. ===============================================================*/

extern rectangle_t result_geometry;
extern string_t result_font_family;
extern int_t result_font_size;

/* Functions. ===============================================================*/

extern void read_result( void );
/* Read new results from STDIN. */

/* End of file. =============================================================*/
